#-------------------------------------------------------------------------------
#
# glcd_demo.py
#
# Plots a number of items to the glcd screen,
# demonstrating the functionality of the module
#
# Stephan Laage-Witt - 26-Dec-2017
#-------------------------------------------------------------------------------

import time
import glcd_module
import math

# initiation -------------------------------------------------------------------

# initiate display, read display width, clear screen and set back light
gl = glcd_module.glcd(32)
max_x = gl.get_max_xy()[0]
gl.clear_screen()
gl.set_light(10)

# draw x-scale -----------------------------------------------------------------
gl.draw_line(10, 31, 191-10, 31, 1)
gl.set_font(1)
for i in range(2, 9):
    gl.draw_line(10 + i * 20, 31, 10 + i * 20, 34, 1)
    label_str = '%2.1f' % float(i-1)
    gl.set_cursor(10 + i * 20, 36)
    gl.draw_center_str(label_str)
    time.sleep(0.01)

#draw y-scale (no labels) ------------------------------------------------------
gl.draw_line(30, 0, 30, 63, 1)

# draw sinus curves ------------------------------------------------------------
array = []
for i in range(0, 192):
    array.append(int(20 * math.sin(i/10)) + 31)
gl.draw_function(192, 0, 1, array)
array = []
for i in range(0, 192):
    array.append(int(32 * math.sin(i/10)) + 31)
gl.draw_function(192, 0, 1, array)
time.sleep(0.05)    # wait a moment until operations above are completed ...
                    # ... in order to synhronize the following I2C read functions
                    # Alternatively, check "buffer empty" signal
                    
# draw main title --------------------------------------------------------------
x_center = max_x // 2
y_start = 7
title_str = "Smart I2C Graphic LCD"
gl.set_font(6)
title_height = gl.get_font_height()
title_width = gl.get_str_width(title_str)
half_width = title_width // 2
gl.draw_filled_rectangle(x_center - half_width - 2, y_start - 2, x_center + half_width + 2, y_start + title_height + 1, 0)
gl.draw_rectangle(x_center - half_width - 3, y_start - 3, x_center + half_width + 3, y_start + title_height + 2, 1)
gl.draw_rectangle(x_center - half_width - 4, y_start - 4, x_center + half_width + 4, y_start + title_height + 3, 1)
gl.set_cursor(x_center - half_width, y_start)
gl.draw_str(title_str)

# draw circle markers ----------------------------------------------------------
# 1st marker, left side
x_mark = 191 - 9
y_mark = 63 - 9
gl.draw_filled_circle(x_mark, y_mark, 7, 0b00000101, 1)
gl.draw_circle(x_mark, y_mark, 9, 0xff, 1)
# 2nd marker, right sid
x_org = 9
y_org = 63 - 9
gl.draw_filled_circle(x_org, y_org, 7, 0b00000101, 1)
gl.draw_circle(x_org, y_org, 9, 0xff, 1)

# draw bottom string -----------------------------------------------------------
bottom_str = "Simple graphics for small systems"
gl.set_font(4)
gl.set_cursor(x_center, 47)
gl.draw_center_str(bottom_str)


